pub struct Watcher { /* private fields */ }Expand description
Daemon monitoring files.
Implementations
sourceimpl Watcher
impl Watcher
sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Resets the watcher’s state.
- clears
self.known_filesandself.new_diffs; - adds
self.tmp_fileandself.init_filetoself.known_files.
sourceimpl Watcher
impl Watcher
sourcepub fn try_read_init(&mut self) -> Res<Option<Init>>
pub fn try_read_init(&mut self) -> Res<Option<Init>>
Reads the init file in the dump directory.
Returns None when
- init file does not exist, or
init_last_modified = Some(t)and the init file was modified more recently thant.
This function is used i) during initialization to read the init file, and ii) to check whether it was overwritten by a new run to relaunch everything.
If the result isn’t None, self.init_last_modified is updated to the date of last
modification of the init file.
sourceimpl Watcher
impl Watcher
sourcepub fn register_new_diffs(&mut self, update_progress: bool) -> Res<bool>
pub fn register_new_diffs(&mut self, update_progress: bool) -> Res<bool>
Gathers and registers new diffs.
- sleeps for
100milliseconds if there are no new diffs; - asserts
self.new_diffs.is_empty(). - returns
trueif something new was discovered. update_progressindicates that thecrate::data::progressneeds to be updated
sourcepub fn gather_new_diffs(
&mut self,
upper_bound: Option<SystemTime>
) -> Res<Option<SystemTime>>
pub fn gather_new_diffs(
&mut self,
upper_bound: Option<SystemTime>
) -> Res<Option<SystemTime>>
Gathers the new diff files.
- diff files to send will be in
self.new_diffs. - assumes
self.new_diffs.is_empty(). - returns
Someif there was at list one new diff found (equivalent to!self.new_diffs.is_empty()) - returns the most recent date of last modification