pub trait Ranged {
type FormatOption: DefaultValueFormatOption;
type ValueType;
fn map(&self, value: &Self::ValueType, limit: (i32, i32)) -> i32;
fn key_points<Hint>(&self, hint: Hint) -> Vec<Self::ValueType, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
where
Hint: KeyPointHint;
fn range(&self) -> Range<Self::ValueType>ⓘNotable traits for Range<A>impl<A> Iterator for Range<A> where
A: Step, type Item = A;;
fn axis_pixel_range(&self, limit: (i32, i32)) -> Range<i32>ⓘNotable traits for Range<A>impl<A> Iterator for Range<A> where
A: Step, type Item = A; { ... }
}Expand description
The trait that indicates we have a ordered and ranged value Which is used to describe any 1D axis.
Required Associated Types
type FormatOption: DefaultValueFormatOption
type FormatOption: DefaultValueFormatOption
This marker decides if Plotters default ValueFormatter implementation should be used. This assicated type can be one of follow two types:
-
DefaultFormatting will allow Plotters automatically impl the formatter based on
Debugtrait, ifDebugtrait is not impl for theSelf::Value, ValueFormatter will not impl unless you impl it manually. -
NoDefaultFormatting Disable the automatical
Debugbased value formatting. Thus you have to impl the ValueFormatter manually.
type ValueType
type ValueType
The type of this value in this range specification
Required Methods
This function maps the value to i32, which is the drawing coordinate
This function gives the key points that we can draw a grid based on this