pub struct OnceLock<T> { /* private fields */ }once_cell)Expand description
A synchronization primitive which can be written to only once.
This type is a thread-safe OnceCell.
Examples
#![feature(once_cell)]
use std::sync::OnceLock;
static CELL: OnceLock<String> = OnceLock::new();
assert!(CELL.get().is_none());
std::thread::spawn(|| {
let value: &String = CELL.get_or_init(|| {
"Hello, World!".to_string()
});
assert_eq!(value, "Hello, World!");
}).join().unwrap();
let value: Option<&String> = CELL.get();
assert!(value.is_some());
assert_eq!(value.unwrap().as_str(), "Hello, World!");Implementations
sourceimpl<T> OnceLock<T>
impl<T> OnceLock<T>
sourcepub const fn new() -> OnceLock<T>
🔬 This is a nightly-only experimental API. (once_cell)
pub const fn new() -> OnceLock<T>
once_cell)Creates a new empty cell.
sourcepub fn get(&self) -> Option<&T>
🔬 This is a nightly-only experimental API. (once_cell)
pub fn get(&self) -> Option<&T>
once_cell)Gets the reference to the underlying value.
Returns None if the cell is empty, or being initialized. This
method never blocks.
sourcepub fn get_mut(&mut self) -> Option<&mut T>
🔬 This is a nightly-only experimental API. (once_cell)
pub fn get_mut(&mut self) -> Option<&mut T>
once_cell)Gets the mutable reference to the underlying value.
Returns None if the cell is empty. This method never blocks.
sourcepub fn set(&self, value: T) -> Result<(), T>
🔬 This is a nightly-only experimental API. (once_cell)
pub fn set(&self, value: T) -> Result<(), T>
once_cell)Sets the contents of this cell to value.
May block if another thread is currently attempting to initialize the cell. The cell is guaranteed to contain a value when set returns, though not necessarily the one provided.
Returns Ok(()) if the cell’s value was set by this call.
Examples
#![feature(once_cell)]
use std::sync::OnceLock;
static CELL: OnceLock<i32> = OnceLock::new();
fn main() {
assert!(CELL.get().is_none());
std::thread::spawn(|| {
assert_eq!(CELL.set(92), Ok(()));
}).join().unwrap();
assert_eq!(CELL.set(62), Err(62));
assert_eq!(CELL.get(), Some(&92));
}sourcepub fn get_or_init<F>(&self, f: F) -> &T where
F: FnOnce() -> T,
🔬 This is a nightly-only experimental API. (once_cell)
pub fn get_or_init<F>(&self, f: F) -> &T where
F: FnOnce() -> T,
once_cell)Gets the contents of the cell, initializing it with f if the cell
was empty.
Many threads may call get_or_init concurrently with different
initializing functions, but it is guaranteed that only one function
will be executed.
Panics
If f panics, the panic is propagated to the caller, and the cell
remains uninitialized.
It is an error to reentrantly initialize the cell from f. The
exact outcome is unspecified. Current implementation deadlocks, but
this may be changed to a panic in the future.
Examples
#![feature(once_cell)]
use std::sync::OnceLock;
let cell = OnceLock::new();
let value = cell.get_or_init(|| 92);
assert_eq!(value, &92);
let value = cell.get_or_init(|| unreachable!());
assert_eq!(value, &92);sourcepub fn get_or_try_init<F, E>(&self, f: F) -> Result<&T, E> where
F: FnOnce() -> Result<T, E>,
🔬 This is a nightly-only experimental API. (once_cell)
pub fn get_or_try_init<F, E>(&self, f: F) -> Result<&T, E> where
F: FnOnce() -> Result<T, E>,
once_cell)Gets the contents of the cell, initializing it with f if
the cell was empty. If the cell was empty and f failed, an
error is returned.
Panics
If f panics, the panic is propagated to the caller, and
the cell remains uninitialized.
It is an error to reentrantly initialize the cell from f.
The exact outcome is unspecified. Current implementation
deadlocks, but this may be changed to a panic in the future.
Examples
#![feature(once_cell)]
use std::sync::OnceLock;
let cell = OnceLock::new();
assert_eq!(cell.get_or_try_init(|| Err(())), Err(()));
assert!(cell.get().is_none());
let value = cell.get_or_try_init(|| -> Result<i32, ()> {
Ok(92)
});
assert_eq!(value, Ok(&92));
assert_eq!(cell.get(), Some(&92))sourcepub fn into_inner(self) -> Option<T>
🔬 This is a nightly-only experimental API. (once_cell)
pub fn into_inner(self) -> Option<T>
once_cell)Consumes the OnceLock, returning the wrapped value. Returns
None if the cell was empty.
Examples
#![feature(once_cell)]
use std::sync::OnceLock;
let cell: OnceLock<String> = OnceLock::new();
assert_eq!(cell.into_inner(), None);
let cell = OnceLock::new();
cell.set("hello".to_string()).unwrap();
assert_eq!(cell.into_inner(), Some("hello".to_string()));sourcepub fn take(&mut self) -> Option<T>
🔬 This is a nightly-only experimental API. (once_cell)
pub fn take(&mut self) -> Option<T>
once_cell)Takes the value out of this OnceLock, moving it back to an uninitialized state.
Has no effect and returns None if the OnceLock hasn’t been initialized.
Safety is guaranteed by requiring a mutable reference.
Examples
#![feature(once_cell)]
use std::sync::OnceLock;
let mut cell: OnceLock<String> = OnceLock::new();
assert_eq!(cell.take(), None);
let mut cell = OnceLock::new();
cell.set("hello".to_string()).unwrap();
assert_eq!(cell.take(), Some("hello".to_string()));
assert_eq!(cell.get(), None);Trait Implementations
impl<T> Eq for OnceLock<T> where
T: Eq,
impl<T> RefUnwindSafe for OnceLock<T> where
T: RefUnwindSafe + UnwindSafe,
impl<T> Send for OnceLock<T> where
T: Send,
impl<T> Sync for OnceLock<T> where
T: Sync + Send,
impl<T> UnwindSafe for OnceLock<T> where
T: UnwindSafe,